@@ -10,7 +10,7 @@ from __future__ import absolute_import, unicode_literals
 
 try:
     from . import stone_validators as bv
-except (SystemError, ValueError):
+except (ImportError, SystemError, ValueError):
     # Catch errors raised when importing a relative module when not in a package.
     # This makes testing this file directly (outside of a package) easier.
     import stone_validators as bv  # type: ignore
@@ -85,8 +85,9 @@ class Union(object):
 
 class Route(object):
 
-    def __init__(self, name, deprecated, arg_type, result_type, error_type, attrs):
+    def __init__(self, name, version, deprecated, arg_type, result_type, error_type, attrs):
         self.name = name
+        self.version = version
         self.deprecated = deprecated
         self.arg_type = arg_type
         self.result_type = result_type
@@ -95,8 +96,9 @@ class Route(object):
         self.attrs = attrs
 
     def __repr__(self):
-        return 'Route({!r}, {!r}, {!r}, {!r}, {!r}, {!r})'.format(
+        return 'Route({!r}, {!r}, {!r}, {!r}, {!r}, {!r}, {!r})'.format(
             self.name,
+            self.version,
             self.deprecated,
             self.arg_type,
             self.result_type,
